﻿
namespace flowerpot.Web
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.ComponentModel.DataAnnotations;
    using System.Data.Objects.DataClasses;
    using System.Linq;
    using System.ServiceModel.DomainServices.Hosting;
    using System.ServiceModel.DomainServices.Server;
    using flowerpot.Web.Resources;

    // The MetadataTypeAttribute identifies ActualizacionMetadata as the class
    // that carries additional metadata for the Actualizacion class.
    [MetadataTypeAttribute(typeof(Actualizacion.ActualizacionMetadata))]
    public partial class Actualizacion
    {

        // This class allows you to attach custom attributes to properties
        // of the Actualizacion class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class ActualizacionMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private ActualizacionMetadata()
            {
            }

            public Ejemplar Ejemplar { get; set; }

            public DateTime Fecha { get; set; }

            public int Id { get; set; }

            public int IdEjemplar { get; set; }

            public string Imagen { get; set; }

            [Required(AllowEmptyStrings = false, ErrorMessage = "Debe rellenar el campo Observaciones")]
            public string Observaciones { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies ComentariosMetadata as the class
    // that carries additional metadata for the Comentarios class.
    [MetadataTypeAttribute(typeof(Comentarios.ComentariosMetadata))]
    public partial class Comentarios
    {

        // This class allows you to attach custom attributes to properties
        // of the Comentarios class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class ComentariosMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private ComentariosMetadata()
            {
            }

            public Ejemplar Ejemplar { get; set; }

            public DateTime Fecha { get; set; }

            public int Id { get; set; }

            public int IdEjemplar { get; set; }

            public int IdUsuario { get; set; }

            [Required(AllowEmptyStrings = false, ErrorMessage = "Debe introducir un Comentario")]
            public string Texto { get; set; }

            public Usuario Usuario { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies EjemplarMetadata as the class
    // that carries additional metadata for the Ejemplar class.
    [MetadataTypeAttribute(typeof(Ejemplar.EjemplarMetadata))]
    public partial class Ejemplar
    {

        // This class allows you to attach custom attributes to properties
        // of the Ejemplar class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class EjemplarMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private EjemplarMetadata()
            {
            }

            public EntityCollection<Actualizacion> Actualizacion { get; set; }

            public EntityCollection<Comentarios> Comentarios { get; set; }

            public Especie Especie { get; set; }

            [Required(AllowEmptyStrings=false,ErrorMessage="Debe rellenar el campo Etiqueta")]
            public string Etiqueta { get; set; }
            
            public DateTime FechaAlta { get; set; }

            [Key]
            public int Id { get; set; }

            public int IdEspecie { get; set; }

            public int IdUsuario { get; set; }

            public Usuario Usuario { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies EspecieMetadata as the class
    // that carries additional metadata for the Especie class.
    [MetadataTypeAttribute(typeof(Especie.EspecieMetadata))]
    public partial class Especie
    {

        // This class allows you to attach custom attributes to properties
        // of the Especie class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class EspecieMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private EspecieMetadata()
            {
            }

            public EntityCollection<Ejemplar> Ejemplar { get; set; }
            
            public int Id { get; set; }

            public string Nombre { get; set; }

            public string NombreComun { get; set; }

        }
    }


    // The MetadataTypeAttribute identifies UsuarioMetadata as the class
    // that carries additional metadata for the Usuario class.
    [MetadataTypeAttribute(typeof(Usuario.UsuarioMetadata))]
    public partial class Usuario
    {

        // This class allows you to attach custom attributes to properties
        // of the Usuario class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class UsuarioMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private UsuarioMetadata()
            {
            }

            public bool Administrador { get; set; }

            public EntityCollection<Comentarios> Comentarios { get; set; }

            public bool Comunidad { get; set; }

            public EntityCollection<Ejemplar> Ejemplar { get; set; }


            [RegularExpression(@"^([\w-\.]+)@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.)|(([\w-]+\.)+))([a-zA-Z]{2,4}|[0-9]{1,3})(\]?)$",
             ErrorMessageResourceName = "ValidationErrorInvalidEmail", ErrorMessageResourceType = typeof(ValidationErrorResources))]
            public string Email { get; set; }

            public int Id { get; set; }

            [CustomValidation(typeof(flowerpot.Web.Services.UserValidator), "AsyncValidateUser")]
            public string Name { get; set; }

            public string Password { get; set; }
        }
    }
}
