﻿namespace flowerpot
{
    using System;
    using System.Windows;
    using System.Windows.Controls;
    using System.Windows.Navigation;
    using flowerpot.Views;

    /// <summary>
    /// <see cref="UserControl"/> class providing the main UI for the application.
    /// </summary>
    public partial class MainPage : UserControl
    {
        /// <summary>
        /// Creates a new <see cref="MainPage"/> instance.
        /// </summary>
        public MainPage()
        {
            Autenticado.Usuario = "";
            Autenticado.IdUsuario = 0;
            Autenticado.Registrado = false;
            Autenticado.Administrador = false;
            InitializeComponent();
        }

        /// <summary>
        /// After the Frame navigates, ensure the <see cref="HyperlinkButton"/> representing the current page is selected
        /// </summary>
        private void ContentFrame_Navigated(object sender, NavigationEventArgs e)
        {
            foreach (UIElement child in LinksStackPanel.Children)
            {
                HyperlinkButton hb = child as HyperlinkButton;
                if (hb != null && hb.NavigateUri != null)
                {
                    if (hb.NavigateUri.ToString().Equals(e.Uri.ToString()))
                    {
                        VisualStateManager.GoToState(hb, "ActiveLink", true);
                    }
                    else
                    {
                        VisualStateManager.GoToState(hb, "InactiveLink", true);
                    }
                }
            }
        }

        /// <summary>
        /// If an error occurs during navigation, show an error window
        /// </summary>
        private void ContentFrame_NavigationFailed(object sender, NavigationFailedEventArgs e)
        {
            e.Handled = true;
            ErrorWindow.CreateNew(e.Exception);
        }

        private void hbLogin_Click(object sender, RoutedEventArgs e)
        {
            if (hbLogin.Content.Equals("Login"))
            {
                Login chldLogin = new Login();
                chldLogin.Closed += new EventHandler(chldLogin_Closed);
                chldLogin.Show();
            }
            else if (hbLogin.Content.Equals("Logout"))
            {
                lblUser.Visibility = System.Windows.Visibility.Collapsed;
                hbLogin.Content = "Login";
                lblUser.Content = "";
                Autenticado.Usuario = "";
                Autenticado.IdUsuario = 0;
                Autenticado.Registrado = false;
                Autenticado.Administrador = false;
            }
        }

        void chldLogin_Closed(object sender, EventArgs e)
        {
            Login chldWind = (Login)sender;

            if ((chldWind.DialogResult == true))
            {

                lblUser.Visibility = System.Windows.Visibility.Visible;
                //Assign The Username to screen
                lblUser.Content = Autenticado.Usuario;
                hbLogin.Content = "Logout";
            }

        }

    }
}