﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Navigation;
using flowerpot.Web;
using System.ServiceModel.DomainServices.Client;
using System.Windows.Media.Imaging;

namespace flowerpot.Views
{
    public partial class ActualizacionesView : Page
    {
        flowerpotDomainContext _Context = new flowerpotDomainContext();

        public ActualizacionesView()
        {
            InitializeComponent();
            btnAdd.Visibility = Autenticado.Propietario | Autenticado.Administrador ? System.Windows.Visibility.Visible : System.Windows.Visibility.Collapsed;
            btnEdit.Visibility = Autenticado.Propietario | Autenticado.Administrador ? System.Windows.Visibility.Visible : System.Windows.Visibility.Collapsed;
            btnDel.Visibility = Autenticado.Propietario | Autenticado.Administrador ? System.Windows.Visibility.Visible : System.Windows.Visibility.Collapsed;
        }

        // Executes when the user navigates to this page.
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            LoadData();
        }

        private void btnAdd_Click(object sender, RoutedEventArgs e)
        {
            //Create a New Actualizacion Object
            Actualizacion actualizacionObject = new Actualizacion();
            actualizacionObject.Fecha = DateTime.Now;
            int ejID = int.Parse(this.NavigationContext.QueryString["ejID"]);
            actualizacionObject.IdEjemplar = ejID;

            //Add to the Collection of Domain DataContext
            _Context.Actualizacions.Add(actualizacionObject);

            //Create a PopUp Child Window Object
            Views.AddActualizacion chldWind = new Views.AddActualizacion();

            chldWind.Title = "Añadir Actualización";

            //Getting the GridLayout Control of the popUp To Be Shown and assign the Newly Created Object
            ((Grid)chldWind.FindName("chldMainContainer")).DataContext = actualizacionObject;


            //Attach The Todo on Close Event handaler
            chldWind.Closed += new EventHandler(chldWind_Closed);


            chldWind.Show();
        }

        void chldWind_Closed(object sender, EventArgs e)
        {
            ChildWindow chldWind = (ChildWindow)sender;
            if ((chldWind.DialogResult == true))
            {
                SubmitOperation so;
                try
                {
                    so = _Context.SubmitChanges(OnSubmitCompleted, null);
                }
                catch (Exception exp)
                {
                    MessageBox.Show(exp.Message);
                }
            }
            else
            {
                _Context.RejectChanges();
            }
        }

        /// <summary>
        /// CallBack Function for SubmitChanges
        /// </summary>
        /// <param name="so"></param>
        private void OnSubmitCompleted(SubmitOperation so)
        {
            if (so.HasError)
            {
                MessageBox.Show(string.Format("Submit Failed: {0}", so.Error.Message));
                so.MarkErrorAsHandled();
            }

            LoadData();
        }


        private void LoadData()
        {
            if (this.NavigationContext.QueryString.ContainsKey("ejID"))
            {
                int ejID = int.Parse(this.NavigationContext.QueryString["ejID"]);
                _Context.Load(_Context.GetActualizacionEjemplarQuery(ejID));
            }
            else
            {
                _Context.Load(_Context.GetActualizacionQuery());
            }
            actualizacionDataGrid.ItemsSource = _Context.Actualizacions;

        }

        private void btnEdit_Click(object sender, RoutedEventArgs e)
        {
            
            if (actualizacionDataGrid.SelectedItem == null)
            {
                MessageBox.Show("Seleccione una Actualización de la lista.");
                return;
            }

            //Creating a new object of Popup
            AddActualizacion chldWind = new AddActualizacion();

            chldWind.Title = "Editar Actualización";

            //Getting the GridLayout Control of the popUp To Be Shown and assign the Selected Item
            ((Grid)chldWind.FindName("chldMainContainer")).DataContext = actualizacionDataGrid.SelectedItem;

            //Add a Event Handaler Which will Execute the Submit The Changes  made to entity Assigned
            chldWind.Closed += new EventHandler(chldWind_Closed);

            chldWind.Show();
        }

        private void btnDel_Click(object sender, RoutedEventArgs e)
        {
            if (actualizacionDataGrid.SelectedItem == null)
            {
                MessageBox.Show("Seleccione una Actualización de la lista.");
                return;
            }

            Actualizacion selectedActualizacion = (Actualizacion)actualizacionDataGrid.SelectedItem;
            if (MessageBox.Show("¿Está seguro que desea borrar la actualización seleccionada?",
                "Confirmación", MessageBoxButton.OKCancel) == MessageBoxResult.OK)
            {
                _Context.Actualizacions.Remove(selectedActualizacion);
                _Context.SubmitChanges(OnSubmitCompleted, null);
            }
        }

    }
}
