﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Navigation;
using flowerpot.Web;
using flowerpot.Views;
using System.ServiceModel.DomainServices.Client;

namespace flowerpot.Views
{
    public partial class EjemplaresView : Page
    {
        flowerpotDomainContext _Context = new flowerpotDomainContext();

        public EjemplaresView()
        {
            InitializeComponent();
            btnAdd.Visibility = Autenticado.Registrado ? System.Windows.Visibility.Visible : System.Windows.Visibility.Collapsed;
            btnEdit.Visibility = Autenticado.Registrado ? System.Windows.Visibility.Visible : System.Windows.Visibility.Collapsed;
            btnDel.Visibility = Autenticado.Registrado ? System.Windows.Visibility.Visible : System.Windows.Visibility.Collapsed;
        }

        // Executes when the user navigates to this page.
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            LoadData();
        }


        private void btnAdd_Click(object sender, RoutedEventArgs e)
        {
            //Create a New Ejemplar Object
            Ejemplar ejemplarObject = new Ejemplar();
            ejemplarObject.FechaAlta = DateTime.Now;
            ejemplarObject.IdUsuario = Autenticado.IdUsuario;

            //Add to the Collection of Domain DataContext
            _Context.Ejemplars.Add(ejemplarObject);

            //Create a PopUp Child Window Object
            Views.AddEjemplar chldWind = new Views.AddEjemplar();

            chldWind.Title = "Añadir Ejemplar";

            flowerpotDomainContext _Context1 = new flowerpotDomainContext();
            EntityQuery<Especie> query = from c in _Context1.GetEspecieQuery() select c;
            LoadOperation<Especie> especieObject = _Context1.Load(query);

            //Getting the GridLayout Control of the popUp To Be Shown and assign the Selected Item
            ((Grid)chldWind.FindName("chldMainContainer")).DataContext = ejemplarObject;          
            ((ComboBox)chldWind.FindName("comboEspecies")).ItemsSource = especieObject.Entities;

            ((Label)chldWind.FindName("lblUsuario")).Visibility = System.Windows.Visibility.Collapsed;
            ((ComboBox)chldWind.FindName("comboUsuarios")).Visibility = System.Windows.Visibility.Collapsed;
            
            //Attach The Todo on Close Event handaler
            chldWind.Closed += new EventHandler(chldWind_Closed);

            chldWind.Show();
        }

        private void btnEdit_Click(object sender, RoutedEventArgs e)
        {
            if (ejemplarDataGrid.SelectedItem == null)
            {
                MessageBox.Show("Seleccione un ejemplar de la lista.");
                return;
            }

            Ejemplar ejemplarSelected = (Ejemplar)ejemplarDataGrid.SelectedItem;
            
            if (!Autenticado.Administrador)
            {
                if (Autenticado.IdUsuario != ejemplarSelected.IdUsuario )
                {
                    MessageBox.Show("No tiene permisos para editar este ejemplar");
                    return;
                }
            }

            //Creating a new object of Popup
            AddEjemplar chldWind = new AddEjemplar();

            chldWind.Title = "Editar Ejemplar";

            flowerpotDomainContext _Context1 = new flowerpotDomainContext();
            EntityQuery<Especie> query = from c in _Context1.GetEspecieQuery() select c;
            LoadOperation<Especie> lop = _Context1.Load(query);

            lop.Completed += ((Authsender, args) =>
            {
                if (lop.HasError)
                {
                    MessageBox.Show(lop.Error.Message);
                }
                else
                {
                    //Getting the GridLayout Control of the popUp To Be Shown and assign the Selected Item
                    ((Grid)chldWind.FindName("chldMainContainer")).DataContext = ejemplarDataGrid.SelectedItem;

                    ((ComboBox)chldWind.FindName("comboEspecies")).ItemsSource = lop.Entities;
                    ((ComboBox)chldWind.FindName("comboEspecies")).SelectedValue = ((Ejemplar)ejemplarDataGrid.SelectedItem).IdEspecie;
                }
            });

            EntityQuery<Usuario> query1 = from c in _Context1.GetUsuarioQuery() select c;
            LoadOperation<Usuario> lop1 = _Context1.Load(query1);

            lop1.Completed += ((Authsender, args) =>
            {
                if (lop1.HasError)
                {
                    MessageBox.Show(lop1.Error.Message);
                }
                else
                {
                    ((ComboBox)chldWind.FindName("comboUsuarios")).ItemsSource = lop1.Entities;
                    ((ComboBox)chldWind.FindName("comboUsuarios")).SelectedValue = ((Ejemplar)ejemplarDataGrid.SelectedItem).IdUsuario;
                }
            });

            //Add a Event Handaler Which will Execute the Submit The Changes  made to entity Assigned
            chldWind.Closed += new EventHandler(chldWind_Closed);

            chldWind.Show();
        }

        void chldWind_Closed(object sender, EventArgs e)
        {
            ChildWindow chldWind = (ChildWindow)sender;
            if ((chldWind.DialogResult == true))
            {
                SubmitOperation so;
                try
                {

                    so = _Context.SubmitChanges(OnSubmitCompleted, null);
                }
                catch (Exception exp)
                {

                    MessageBox.Show(exp.Message);
                }
            }
            else
            {
                _Context.RejectChanges();
            }
        }

        /// <summary>
        /// CallBack Function for SubmitChanges
        /// </summary>
        /// <param name="so"></param>
        private void OnSubmitCompleted(SubmitOperation so)
        {
            if (so.HasError)
            {
                MessageBox.Show(string.Format("Submit Failed: {0}", so.Error.Message));
                so.MarkErrorAsHandled();
            }

            LoadData();
        }

        private void LoadData()
        {
            _Context.Load(_Context.GetEjemplarQuery());
            ejemplarDataGrid.ItemsSource = _Context.Ejemplars;

        }

        private void btnDel_Click(object sender, RoutedEventArgs e)
        {
            if (ejemplarDataGrid.SelectedItem == null)
            {
                MessageBox.Show("Seleccione un ejemplar de la lista.");
                return;
            }

            Ejemplar selectedEjemplar = (Ejemplar)ejemplarDataGrid.SelectedItem;

            if (!Autenticado.Administrador)
            {
                if (Autenticado.IdUsuario != selectedEjemplar.IdUsuario)
                {
                    MessageBox.Show("No tiene permisos para borrar este ejemplar");
                    return;
                }
            }
                        
            if (MessageBox.Show("Está seguro que desea borrar el ejemplar " + selectedEjemplar.Etiqueta +
                "?", "Confirmación", MessageBoxButton.OKCancel) == MessageBoxResult.OK)
            {
                _Context.Ejemplars.Remove(selectedEjemplar);
                _Context.SubmitChanges(OnSubmitCompleted, null);

            }
        }
    }
}
