﻿namespace flowerpot
{
    using System;
    using System.Windows.Controls;
    using System.Windows.Navigation;
    using System.Windows.Browser;
    using flowerpot.Web;
    using System.Windows;
    using flowerpot.Views;
    using flowerpot;

    /// <summary>
    /// Home page for the application.
    /// </summary>
    public partial class Home : Page
    {
        flowerpotDomainContext _Context = new flowerpotDomainContext();
        /// <summary>
        /// Creates a new <see cref="Home"/> instance.
        /// </summary>
        public Home()
        {
            InitializeComponent();  
        }

        /// <summary>
        /// Executes when the user navigates to this page.
        /// </summary>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            especieComboBox.ItemsSource = _Context.Especies;
            usuarioComboBox.ItemsSource = _Context.Usuarios;
            ejemplarDataGrid.ItemsSource = _Context.Ejemplars;
            _Context.Load(_Context.GetEspecieQuery());
            _Context.Load(_Context.GetUsuarioQuery());
        }

        private void especieComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (especieComboBox.SelectedIndex != -1)
            {
                int espID = ((Especie)especieComboBox.SelectedItem).Id;

                if (_Context.EntityContainer != null)
                {
                    _Context.EntityContainer.GetEntitySet<Ejemplar>().Clear();
                }

                _Context.Load(_Context.GetEjemplarEspecieQuery(espID));
                usuarioComboBox.SelectedIndex = -1;
            }
        }


        private void btnActualizaciones_Click(object sender, RoutedEventArgs e)
        {
            if (ejemplarDataGrid.SelectedItem == null)
            {
                MessageBox.Show("Seleccione un ejemplar de la lista.");
            }
            else
            {   
                int usuId = ((Ejemplar)ejemplarDataGrid.SelectedItem).IdUsuario;
                Autenticado.Propietario = (usuId == Autenticado.IdUsuario);
                int ejID = ((Ejemplar)ejemplarDataGrid.SelectedItem).Id;

                NavigationService.Navigate(new Uri("/ActualizacionesView?ejID=" + ejID.ToString(), UriKind.Relative));
            }
            
            
        }

        private void btnComentarios_Click(object sender, RoutedEventArgs e)
        {
            if (ejemplarDataGrid.SelectedItem == null)
            {
                MessageBox.Show("Seleccione un ejemplar de la lista.");
            }
            else
            {
                int usuId = ((Ejemplar)ejemplarDataGrid.SelectedItem).IdUsuario;
                Autenticado.Propietario = (usuId == Autenticado.IdUsuario);
                int ejID = ((Ejemplar)ejemplarDataGrid.SelectedItem).Id;
                NavigationService.Navigate(new Uri("/ComentariosView?ejID=" + ejID.ToString(), UriKind.Relative));
            }
        }

        private void usuarioComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (usuarioComboBox.SelectedIndex != -1)
            {
                int usuID = ((Usuario)usuarioComboBox.SelectedItem).Id;

                if (_Context.EntityContainer != null)
                {
                    _Context.EntityContainer.GetEntitySet<Ejemplar>().Clear();
                }

                _Context.Load(_Context.GetEjemplarUsuarioQuery(usuID));
                especieComboBox.SelectedIndex = -1;
            }
        }

    }
}