﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Navigation;
using flowerpot.Web;
using System.ServiceModel.DomainServices.Client;
using flowerpot.Views;

namespace flowerpot.Views
{
    public partial class UsuariosView : Page
    {
        flowerpotDomainContext _Context = new flowerpotDomainContext();

        public UsuariosView()
        {
            InitializeComponent();
        }

        // Executes when the user navigates to this page.
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            LoadData();
        }

        private void btnAdd_Click(object sender, RoutedEventArgs e)
        {
            //Create a New Usuario Object
            Usuario usuarioObject = new Usuario();

            //Add to the Collection of Domain DataContext
            _Context.Usuarios.Add(usuarioObject);

            //Create a PopUp Child Window Object
            Views.AddUsuario chldWind = new Views.AddUsuario();

            chldWind.Title = "Añadir Usuario";

            //Getting the GridLayout Control of the popUp To Be Shown and assign the Newly Created Object
            ((Grid)chldWind.FindName("chldMainContainer")).DataContext = usuarioObject;


            //Attach The Todo on Close Event handaler
            chldWind.Closed += new EventHandler(chldWind_Closed);


            chldWind.Show();
        }

        void chldWind_Closed(object sender, EventArgs e)
        {
            ChildWindow chldWind = (ChildWindow)sender;
            if ((chldWind.DialogResult == true))
            {
                SubmitOperation so;
                try
                {

                    so = _Context.SubmitChanges(OnSubmitCompleted, null);
                }
                catch (Exception exp)
                {

                    MessageBox.Show(exp.Message);
                }
            }
            else
            {
                _Context.RejectChanges();
            }
        }

        /// <summary>
        /// CallBack Function for SubmitChanges
        /// </summary>
        /// <param name="so"></param>
        private void OnSubmitCompleted(SubmitOperation so)
        {
            if (so.HasError)
            {
                MessageBox.Show(string.Format("Submit Failed: {0}", so.Error.Message));
                so.MarkErrorAsHandled();
            }

            LoadData();
        }


        private void LoadData()
        {

            
            if (!Autenticado.Administrador)
            {
                if (Autenticado.Registrado)
                {
                    _Context.Load(_Context.GetUsuarioIdQuery(Autenticado.IdUsuario));
                    btnDel.Visibility = System.Windows.Visibility.Collapsed;
                }

                else
                {
                    usuarioDataGrid.Visibility = System.Windows.Visibility.Collapsed;
                    btnEdit.Visibility = System.Windows.Visibility.Collapsed;
                    btnDel.Visibility = System.Windows.Visibility.Collapsed;
                    _Context.Load(_Context.GetUsuarioQuery());
                }
            }
            else
            {
                _Context.Load(_Context.GetUsuarioQuery());
            }

            usuarioDataGrid.ItemsSource = _Context.Usuarios;           
        }

        private void btnEdit_Click(object sender, RoutedEventArgs e)
        {

            if (usuarioDataGrid.SelectedItem == null)
            {
                MessageBox.Show("Seleccione un usuario de la lista.");
                return;
            }
            //Creating a new object of Popup
            AddUsuario chldWind = new AddUsuario();

            chldWind.Title = "Editar Usuario";

            //Getting the GridLayout Control of the popUp To Be Shown and assign the Selected Item
            ((Grid)chldWind.FindName("chldMainContainer")).DataContext = usuarioDataGrid.SelectedItem;


            //Add a Event Handaler Which will Execute the Submit The Changes  made to entity Assigned
            chldWind.Closed += new EventHandler(chldWind_Closed);

            chldWind.Show();
        }

        private void btnDel_Click(object sender, RoutedEventArgs e)
        {
            if (usuarioDataGrid.SelectedItem == null)
            {
                MessageBox.Show("Seleccione un usuario de la lista.");
                return;
            } 
            
            Usuario selectedUsario = (Usuario)usuarioDataGrid.SelectedItem;
            if (MessageBox.Show("¿Está seguro que desea borrar el usuario " + selectedUsario.Name +
                " ?", "Confirmación", MessageBoxButton.OKCancel) == MessageBoxResult.OK)
            {
                _Context.Usuarios.Remove(selectedUsario);
                _Context.SubmitChanges(OnSubmitCompleted, null);

            }
        }

    }
}
